﻿/*
 * Thread Proxy Mediator Pattern Example
 * Copyright (C) 2008 Michael Birken
 * 
 * This file is part of Thread Proxy Mediator Pattern Example.
 *
 * Thread Proxy Mediator Pattern Example is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published 
 * by the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * Thread Proxy Mediator Pattern Example is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 */

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace WPFExample {

  public partial class DividerWindow : Window, IDividerWindow {
    public DividerWindow() {
      InitializeComponent();
    }

    private void DivideButton_Click(object sender, RoutedEventArgs e) {
      divideButton.IsEnabled = false;

      ProgressWindow progressWindow = new ProgressWindow();
      progressWindow.Owner = this;

      DivisionMediator divisionMediator = new DivisionMediator();

      IDividerWindow dividerWindowProxy = ThreadProxyFactory.createProxy<IDividerWindow>(this, Dispatcher);
      IProgressWindow progressWindowProxy 
          = ThreadProxyFactory.createProxy<IProgressWindow>(progressWindow, Dispatcher);
      IDivisionMediator divisionMediatorProxy = ThreadProxyFactory.createProxy<IDivisionMediator>(divisionMediator);
      progressWindow.DivisionMediatorProxy = divisionMediatorProxy;

      divisionMediatorProxy.Divide(
          dividendTextBox.Text, divisorTextBox.Text, dividerWindowProxy, progressWindowProxy);
    }

    #region IDividerWindow Members

    public void DisplayQuotient(string quotient) {
      quotientLabel.Content = quotient;
      divideButton.IsEnabled = true;
    }

    public void ShowError(string errorMessage) {
      MessageBox.Show(this, errorMessage, "Division Error");
      divideButton.IsEnabled = true;
    }

    #endregion
  }

  public interface IDividerWindow {
    void DisplayQuotient(string quotient);
    void ShowError(string errorMessage);
  }
}
