﻿/*
 * Thread Proxy Mediator Pattern Example
 * Copyright (C) 2008 Michael Birken
 * 
 * This file is part of Thread Proxy Mediator Pattern Example.
 *
 * Thread Proxy Mediator Pattern Example is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published 
 * by the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * Thread Proxy Mediator Pattern Example is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 */

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace WPFExample {
  public class DivisionMediator : IDivisionMediator {

    private volatile Divider divider = new Divider();

    public void Divide(string dividend, string divisor,
        IDividerWindow dividerWindowProxy, IProgressWindow progressWindowProxy) {
      
      int a = 0;
      int b = 0;
      try {
        a = Int32.Parse(dividend);
      } catch {
        dividerWindowProxy.ShowError("Dividend is not a valid number.");
        return;
      }
      try {
        b = Int32.Parse(divisor);
      } catch {
        dividerWindowProxy.ShowError("Divisor is not a valid number.");
        return;
      }

      progressWindowProxy.Display();

      int quotient;
      bool canceled;
      try {
        divider.Divide(a, b, out quotient, out canceled, percent => progressWindowProxy.DisplayProgress(percent));
      } catch (Exception e) {
        progressWindowProxy.DisplayProgress(100);
        dividerWindowProxy.DisplayQuotient("?");
        dividerWindowProxy.ShowError(e.Message);
        return;
      }

      if (canceled) {
        progressWindowProxy.DisplayProgress(100);
        dividerWindowProxy.DisplayQuotient("?");
      } else {
        dividerWindowProxy.DisplayQuotient(quotient.ToString());
      }
    }

    public void CancelDivision() {
      divider.CancelDivision();
    }
  }

  public interface IDivisionMediator {
    void Divide(string dividend, string divisor,
        IDividerWindow dividerWindowProxy, IProgressWindow progressWindowProxy);
    void CancelDivision();
  }
}
