﻿/*
 * Thread Proxy Mediator Pattern Example
 * Copyright (C) 2008 Michael Birken
 * 
 * This file is part of Thread Proxy Mediator Pattern Example.
 *
 * Thread Proxy Mediator Pattern Example is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published 
 * by the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * Thread Proxy Mediator Pattern Example is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 */

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Shapes;

namespace WPFExample {
  /// <summary>
  /// Interaction logic for ProgressWindow.xaml
  /// </summary>
  public partial class ProgressWindow : Window, IProgressWindow {

    private IDivisionMediator divisionMediatorProxy;

    public ProgressWindow() {
      InitializeComponent();
    }

    public IDivisionMediator DivisionMediatorProxy {
      set {
        divisionMediatorProxy = value;
      }
    }

    private void cancelButton_Click(object sender, RoutedEventArgs e) {
      cancelButton.IsEnabled = false;
      divisionMediatorProxy.CancelDivision();  
    }

    private void Window_Closed(object sender, EventArgs e) {
      cancelButton.IsEnabled = false;
      divisionMediatorProxy.CancelDivision(); 
    }

    #region IProgressWindow Members

    public void DisplayProgress(int percent) {
      progressBar.Value = percent;
      if (percent == 100) {
        Close();
      }
    }

    public void Display() {
      ShowDialog();
    }

    #endregion
  }

  public interface IProgressWindow {
    void DisplayProgress(int percent);
    void Display();
  }
}
