﻿/*
 * Thread Proxy Mediator Pattern Example
 * Copyright (C) 2008 Michael Birken
 * 
 * This file is part of Thread Proxy Mediator Pattern Example.
 *
 * Thread Proxy Mediator Pattern Example is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published 
 * by the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * Thread Proxy Mediator Pattern Example is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 */

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace WindowsFormsExample {
  public partial class DividerForm : Form, IDividerForm {
    public DividerForm() {
      InitializeComponent();
    }

    private void divideButton_Click(object sender, EventArgs e) {

      divideButton.Enabled = false;

      ProgressForm progressForm = new ProgressForm();
      progressForm.Owner = this;

      DivisionMediator divisionMediator = new DivisionMediator();

      IDividerForm dividerFormProxy = ThreadProxyFactory.createProxy<IDividerForm>(this, this);
      IProgressForm progressFormProxy = ThreadProxyFactory.createProxy<IProgressForm>(progressForm, this);
      IDivisionMediator divisionMediatorProxy = ThreadProxyFactory.createProxy<IDivisionMediator>(divisionMediator);
      progressForm.DivisionMediatorProxy = divisionMediatorProxy;

      divisionMediatorProxy.Divide(dividendTextBox.Text, divisorTextBox.Text, dividerFormProxy, progressFormProxy);
    }

    public void DisplayQuotient(string quotient) {
      quotientLabel.Text = quotient;
      divideButton.Enabled = true;
    }

    public void ShowError(string errorMessage) {
      MessageBox.Show(this, errorMessage, "Division Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
      divideButton.Enabled = true;
    }
  }

  public interface IDividerForm {
    void DisplayQuotient(string quotient);
    void ShowError(string errorMessage);
  }
}
