﻿/*
 * Thread Proxy Mediator Pattern Example
 * Copyright (C) 2008 Michael Birken
 * 
 * This file is part of Thread Proxy Mediator Pattern Example.
 *
 * Thread Proxy Mediator Pattern Example is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published 
 * by the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * Thread Proxy Mediator Pattern Example is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 */

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading;

namespace WindowsFormsExample {
  public class HypotheticalDivisionMediatorProxy : IDivisionMediator {

    private IDivisionMediator target;

    public HypotheticalDivisionMediatorProxy(IDivisionMediator target) {
      this.target = target;
    }

    public void Divide(string dividend, string divisor, 
        IDividerForm dividerFormProxy, IProgressForm progressFormProxy) {
      DivideClass divideClass = new DivideClass(target);
      divideClass.dividend = dividend;
      divideClass.divisor = divisor;
      divideClass.dividerFormProxy = dividerFormProxy;
      divideClass.progressFormProxy = progressFormProxy;
      ThreadPool.QueueUserWorkItem(new WaitCallback(divideClass.Run));
    }

    public void CancelDivision() {
      CancelDivisionClass cancelDivisionClass = new CancelDivisionClass(target);
      ThreadPool.QueueUserWorkItem(new WaitCallback(cancelDivisionClass.Run));
    }
  }

  public class DivideClass {
    
    private IDivisionMediator target;
    public string dividend;
    public string divisor;
    public IDividerForm dividerFormProxy;
    public IProgressForm progressFormProxy;

    public DivideClass(IDivisionMediator target) {
      this.target = target;
    }
    
    public void Run(object stateInfo) {
      target.Divide(dividend, divisor, dividerFormProxy, progressFormProxy);
    }
  }

  public class CancelDivisionClass {

    private IDivisionMediator target;

    public CancelDivisionClass(IDivisionMediator target) {
      this.target = target;
    }

    public void Run(object stateInfo) {
      target.CancelDivision();
    }
  }
}
